# -*- coding: UTF-8 -*-
from setuptools import setup, find_packages
setup(name='xesrepair',
      version='0.2.5',
      description='学而思编程助手专属工具库',
      classifiers=[
          'Programming Language :: Python',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
      ],
      url='https://www.python.org/',
      install_requires=[],
      author='zhushaodong123',
      author_email='',
      license='NEU',
      packages=find_packages(),
      package_data={"": ["*.pyc"]},
      zip_safe=True
      )
